// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KGAPI_VERSION_H
#define KGAPI_VERSION_H

#define KGAPI_VERSION_STRING "6.1.2"
#define KGAPI_VERSION_MAJOR 6
#define KGAPI_VERSION_MINOR 1
#define KGAPI_VERSION_PATCH 2
#define KGAPI_VERSION ((6<<16)|(1<<8)|(2))

#endif
